@@ -11,25 +11,26 @@
 # Modules and declarations
 ##############################################################################
 
-package App::DocKnot::Spin 5.00;
+package App::DocKnot::Spin 6.00;
 
 use 5.024;
 use autodie;
 use warnings;
 
+use App::DocKnot::Spin::Pointer;
 use App::DocKnot::Spin::RSS;
 use App::DocKnot::Spin::Sitemap;
 use App::DocKnot::Spin::Thread;
 use App::DocKnot::Spin::Versions;
+use App::DocKnot::Util qw(is_newer print_checked print_fh);
 use Carp qw(croak);
 use Cwd qw(getcwd realpath);
 use File::Basename qw(fileparse);
 use File::Copy qw(copy);
 use File::Find qw(find finddepth);
-use File::Spec      ();
+use File::Spec ();
 use Git::Repository ();
-use List::SomeUtils qw(all);
-use IPC::System::Simple qw(capture systemx);
+use IPC::System::Simple qw(capture);
 use Pod::Thread 3.00 ();
 use POSIX qw(strftime);
 
@@ -45,52 +46,10 @@ my @EXCLUDES = (
 # used to embed a link to the software that generated the page.
 my $URL = 'https://www.eyrie.org/~eagle/software/web/';
 
-##############################################################################
-# Utility functions
-##############################################################################
-
-# Check if a file, which may not exist, is newer than another list of files.
-#
-# $file   - File whose timestamp to compare
-# @others - Other files to compare against
-#
-# Returns: True if $file exists and is newer than @others, false otherwise
-sub _is_newer {
-    my ($file, @others) = @_;
-    return if !-e $file;
-    my $file_mtime    = (stat($file))[9];
-    my @others_mtimes = map { (stat)[9] } @others;
-    return all { $file_mtime >= $_ } @others_mtimes;
-}
-
 ##############################################################################
 # Output
 ##############################################################################
 
-# print with error checking.  autodie unfortunately can't help us because
-# print can't be prototyped and hence can't be overridden.
-sub _print_checked {
-    my (@args) = @_;
-    print @args or croak('print failed');
-    return;
-}
-
-# print with error checking and an explicit file handle.  autodie
-# unfortunately can't help us because print can't be prototyped and
-# hence can't be overridden.
-#
-# $fh   - Output file handle
-# $file - File name for error reporting
-# @args - Remaining arguments to print
-#
-# Returns: undef
-#  Throws: Text exception on output failure
-sub _print_fh {
-    my ($fh, $file, @args) = @_;
-    print {$fh} @args or croak("cannot write to $file: $!");
-    return;
-}
-
 # Build te page footer, which consists of the navigation links, the regular
 # signature, and the last modified date.
 #
@@ -106,7 +65,7 @@ sub _print_fh {
 # Returns: HTML output
 sub _footer {
     my ($self, $source, $out_path, $id, @templates) = @_;
-    my $output  = q{};
+    my $output = q{};
     my $in_tree = 0;
     if ($self->{source} && $source =~ m{ \A \Q$self->{source}\E }xms) {
         $in_tree = 1;
@@ -116,7 +75,7 @@ sub _footer {
     if ($self->{sitemap} && $self->{output}) {
         my $page = $out_path;
         $page =~ s{ \A \Q$self->{output}\E }{}xms;
-        $output .= join(q{}, $self->{sitemap}->navbar($page));
+        $output .= join(q{}, $self->{sitemap}->navbar($page)) . "\n";
     }
 
     # Figure out the modification dates.  Use the RCS/CVS Id if available,
@@ -187,15 +146,15 @@ sub _write_converter_output {
         if ($self->{sitemap} && $line =~ m{ \A </head> }xmsi) {
             my @links = $self->{sitemap}->links($page);
             if (@links) {
-                _print_fh($out_fh, $output, @links);
+                print_fh($out_fh, $output, @links);
             }
         }
-        _print_fh($out_fh, $output, $line);
+        print_fh($out_fh, $output, $line);
         if ($line =~ m{ <body }xmsi) {
             if ($self->{sitemap}) {
                 my @navbar = $self->{sitemap}->navbar($page);
                 if (@navbar) {
-                    _print_fh($out_fh, $output, @navbar);
+                    print_fh($out_fh, $output, @navbar);
                 }
             }
             last;
@@ -209,13 +168,13 @@ sub _write_converter_output {
     my $line;
     while (defined($line = shift($page_ref->@*))) {
         last if $line =~ m{ </body> }xmsi;
-        _print_fh($out_fh, $output, $line);
+        print_fh($out_fh, $output, $line);
     }
 
     # Add the footer and finish with the output.
-    _print_fh($out_fh, $output, $footer->($blurb, $docid));
+    print_fh($out_fh, $output, $footer->($blurb, $docid));
     if (defined($line)) {
-        _print_fh($out_fh, $output, $line, $page_ref->@*);
+        print_fh($out_fh, $output, $line, $page_ref->@*);
     }
     close($out_fh);
     return;
@@ -232,7 +191,7 @@ sub _write_converter_output {
 sub _cl2xhtml {
     my ($self, $source, $output, $options, $style) = @_;
     $style ||= $self->{style_url} . 'changelog.css';
-    my @page   = capture("cl2xhtml $options -s $style $source");
+    my @page = capture("cl2xhtml $options -s $style $source");
     my $footer = sub {
         my ($blurb, $id) = @_;
         if ($blurb) {
@@ -261,7 +220,7 @@ sub _cvs2xhtml {
     $options .= " -s $style";
 
     # Run the converter and write the output.
-    my @page   = capture("(cd $dir && cvs log $name) | cvs2xhtml $options");
+    my @page = capture("(cd $dir && cvs log $name) | cvs2xhtml $options");
     my $footer = sub {
         my ($blurb, $id, $file) = @_;
         if ($blurb) {
@@ -279,7 +238,7 @@ sub _cvs2xhtml {
 sub _faq2html {
     my ($self, $source, $output, $options, $style) = @_;
     $style ||= $self->{style_url} . 'faq.css';
-    my @page   = capture("faq2html $options -s $style $source");
+    my @page = capture("faq2html $options -s $style $source");
     my $footer = sub {
         my ($blurb, $id, $file) = @_;
         if ($blurb) {
@@ -357,9 +316,9 @@ sub _read_pointer {
 
     # Read the pointer file.
     open(my $pointer, '<', $file);
-    my $master  = <$pointer>;
+    my $master = <$pointer>;
     my $options = <$pointer>;
-    my $style   = <$pointer>;
+    my $style = <$pointer>;
     close($pointer);
 
     # Clean up the contents.
@@ -397,7 +356,7 @@ sub _process_file {
             return;
         }
     }
-    my $input  = $File::Find::name;
+    my $input = $File::Find::name;
     my $output = $input;
     $output =~ s{ \A \Q$self->{source}\E }{$self->{output}}xms
       or die "input file $file out of tree\n";
@@ -407,12 +366,14 @@ sub _process_file {
     # Conversion rules for pointers.  The key is the extension, the first
     # value is the name of the command for the purposes of output, and the
     # second is the name of the method to run.
+    #<<<
     my %rules = (
         changelog => ['cl2xhtml',   '_cl2xhtml'],
         faq       => ['faq2html',   '_faq2html'],
         log       => ['cvs2xhtml',  '_cvs2xhtml'],
         rpod      => ['pod2thread', '_pod2html'],
     );
+    #>>>
 
     # Figure out what to do with the input.
     if (-d $file) {
@@ -420,15 +381,23 @@ sub _process_file {
         if (-e $output && !-d $output) {
             die "cannot replace $output with a directory\n";
         } elsif (!-d $output) {
-            _print_checked("Creating $shortout\n");
+            print_checked("Creating $shortout\n");
             mkdir($output, 0755);
         }
         my $rss_path = File::Spec->catfile($file, '.rss');
         if (-e $rss_path) {
             $self->{rss}->generate($rss_path, $file);
         }
+    } elsif ($file =~ m{ [.] spin \z }xms) {
+        $output =~ s{ [.] spin \z }{.html}xms;
+        $shortout =~ s{ [.] spin \z }{.html}xms;
+        $self->{generated}{$output} = 1;
+        if ($self->{pointer}->is_out_of_date($input, $output)) {
+            print_checked("Converting $shortout\n");
+            $self->{pointer}->spin_pointer($input, $output);
+        }
     } elsif ($file =~ m{ [.] th \z }xms) {
-        $output   =~ s{ [.] th \z }{.html}xms;
+        $output =~ s{ [.] th \z }{.html}xms;
         $shortout =~ s{ [.] th \z }{.html}xms;
         $self->{generated}{$output} = 1;
 
@@ -438,29 +407,29 @@ sub _process_file {
             my $relative = $input;
             $relative =~ s{ ^ \Q$self->{source}\E / }{}xms;
             my $time = $self->{versions}->latest_release($relative);
-            return if _is_newer($output, $file) && (stat($output))[9] >= $time;
+            return if is_newer($output, $file) && (stat($output))[9] >= $time;
         } else {
-            return if _is_newer($output, $file);
+            return if is_newer($output, $file);
         }
 
         # The output file is not newer.  Respin it.
-        _print_checked("Spinning $shortout\n");
+        print_checked("Spinning $shortout\n");
         $self->{thread}->spin_thread_file($input, $output);
     } else {
         my ($extension) = ($file =~ m{ [.] ([^.]+) \z }xms);
         if (defined($extension) && $rules{$extension}) {
             my ($name, $sub) = $rules{$extension}->@*;
-            $output   =~ s{ [.] \Q$extension\E \z }{.html}xms;
+            $output =~ s{ [.] \Q$extension\E \z }{.html}xms;
             $shortout =~ s{ [.] \Q$extension\E \z }{.html}xms;
             $self->{generated}{$output} = 1;
             my ($source, $options, $style) = $self->_read_pointer($input);
-            return if _is_newer($output, $input, $source);
-            _print_checked("Running $name for $shortout\n");
+            return if is_newer($output, $input, $source);
+            print_checked("Running $name for $shortout\n");
             $self->$sub($source, $output, $options, $style);
         } else {
             $self->{generated}{$output} = 1;
-            return if _is_newer($output, $file);
-            _print_checked("Updating $shortout\n");
+            return if is_newer($output, $file);
+            print_checked("Updating $shortout\n");
             copy($file, $output)
               or die "copy of $input to $output failed: $!\n";
         }
@@ -483,7 +452,7 @@ sub _delete_files {
     return if $self->{generated}{$file};
     my $shortfile = $file;
     $shortfile =~ s{ ^ \Q$self->{output}\E }{...}xms;
-    _print_checked("Deleting $shortfile\n");
+    print_checked("Deleting $shortfile\n");
     if (-d $file) {
         rmdir($file);
     } else {
@@ -522,12 +491,14 @@ sub new {
     }
 
     # Create and return the object.
+    #<<<
     my $self = {
         delete    => $args_ref->{delete},
         excludes  => [@excludes],
         rss       => App::DocKnot::Spin::RSS->new(),
         style_url => $style_url,
     };
+    #>>>
     bless($self, $class);
     return $self;
 }
@@ -555,7 +526,7 @@ sub spin {
 
     # Canonicalize and check output.
     if (!-d $output) {
-        _print_checked("Creating $output\n");
+        print_checked("Creating $output\n");
         mkdir($output, 0755);
     }
     $output = realpath($output) or die "cannot canonicalize $output: $!\n";
@@ -584,6 +555,7 @@ sub spin {
     }
 
     # Create a new thread converter object.
+    #<<<
     $self->{thread} = App::DocKnot::Spin::Thread->new(
         {
             output      => $output,
@@ -593,15 +565,24 @@ sub spin {
             versions    => $self->{versions},
         },
     );
+    #>>>
+
+    # Create the processor for pointers.
+    #<<<
+    $self->{pointer} = App::DocKnot::Spin::Pointer->new(
+        {
+            output      => $output,
+            sitemap     => $self->{sitemap},
+            'style-url' => $self->{style_url},
+            thread      => $self->{thread},
+        },
+    );
+    #>>>
 
     # Process the input tree.
-    find(
-        {
-            preprocess => sub { my @files = sort(@_); return @files },
-            wanted     => sub { $self->_process_file(@_) },
-        },
-        $input,
-    );
+    my $preprocess = sub { my @files = sort(@_); return @files };
+    my $wanted = sub { $self->_process_file(@_) };
+    find({ preprocess => $preprocess, wanted => $wanted }, $input);
     if ($self->{delete}) {
         finddepth(sub { $self->_delete_files(@_) }, $output);
     }
@@ -632,8 +613,9 @@ App::DocKnot::Spin - Static site builder supporting thread macro language
 
 =head1 REQUIREMENTS
 
-Perl 5.24 or later and the modules Git::Repository, Image::Size, and
-Pod::Thread, all of which are available from CPAN.  Also expects to find
+Perl 5.24 or later and the modules Git::Repository, Image::Size,
+List::SomeUtils, Path::Tiny, Pod::Thread, Template (part of Template Toolkit),
+and YAML::XS, all of which are available from CPAN.  Also expects to find
 B<faq2html>, B<cvs2xhtml>, and B<cl2xhtml> on the user's PATH to convert
 certain types of files.
 
